@@ -21,6 +21,7 @@ from astropy.coordinates.representation import (
 )
 from astropy.time import Time
 
+from sunpy import log
 from sunpy.sun.constants import radius as _RSUN
 from sunpy.time.time import _variables_for_parse_time_docstring
 from sunpy.util.decorators import add_common_docstring
@@ -283,6 +284,19 @@ class HeliographicStonyhurst(BaseHeliographic):
     """
     name = "heliographic_stonyhurst"
 
+    def _apply_diffrot(self, duration, rotation_model):
+        oldrepr = self.spherical
+
+        from sunpy.physics.differential_rotation import diff_rot
+        log.debug(f"Applying {duration} of solar rotation")
+        newlon = oldrepr.lon + diff_rot(duration,
+                                        oldrepr.lat,
+                                        rot_type=rotation_model,
+                                        frame_time='sidereal')
+        newrepr = SphericalRepresentation(newlon, oldrepr.lat, oldrepr.distance)
+
+        return self.realize_frame(newrepr)
+
 
 @add_common_docstring(**_frame_parameters())
 class HeliographicCarrington(BaseHeliographic):
@@ -503,6 +517,25 @@ class Helioprojective(SunPyBaseCoordinateFrame):
     rsun = QuantityAttribute(default=_RSUN, unit=u.km)
     observer = ObserverCoordinateAttribute(HeliographicStonyhurst)
 
+    @property
+    def angular_radius(self):
+        """
+        Angular radius of the Sun as seen by the observer.
+
+        The ``rsun`` frame attribute is the radius of the Sun in length units.
+        The tangent vector from the observer to the edge of the Sun forms a
+        right-angle triangle with the radius of the Sun as the far side and the
+        Sun-observer distance as the hypotenuse. Thus, the sine of the angular
+        radius of the Sun is ratio of these two distances.
+        """
+        from sunpy.coordinates.sun import _angular_radius  # avoiding a circular import
+
+        if not isinstance(self.observer, HeliographicStonyhurst):
+            if self.observer is None:
+                raise ValueError("The observer must be defined, not `None`.")
+            raise ValueError("The observer must be fully defined by specifying `obstime`.")
+        return _angular_radius(self.rsun, self.observer.radius)
+
     def make_3d(self):
         """
         This method calculates the third coordinate of the Helioprojective
