@@ -1,11 +1,17 @@
-import warnings
+import numpy as np
 
 import astropy.units as u
 import astropy.wcs.utils
-from astropy.coordinates import BaseCoordinateFrame
+from astropy.coordinates import (
+    ITRS,
+    BaseCoordinateFrame,
+    CartesianRepresentation,
+    SkyCoord,
+    SphericalRepresentation,
+)
 from astropy.wcs import WCS
 
-from sunpy.util.exceptions import SunpyUserWarning
+from sunpy import log
 from .frames import (
     BaseCoordinateFrame,
     Heliocentric,
@@ -17,6 +23,65 @@ from .frames import (
 
 __all__ = ['solar_wcs_frame_mapping', 'solar_frame_to_wcs_mapping']
 
+try:
+    # TODO: Remove vendored version after Astropy 5.0
+    from astropy.wcs.utils import obsgeo_to_frame
+except ImportError:
+    def obsgeo_to_frame(obsgeo, obstime):
+        """
+        Convert a WCS obsgeo property into an `~builtin_frames.ITRS` coordinate frame.
+
+        Parameters
+        ----------
+        obsgeo : array-like
+            A shape ``(6, )`` array representing ``OBSGEO-[XYZ], OBSGEO-[BLH]`` as
+            returned by ``WCS.wcs.obsgeo``.
+
+        obstime : time-like
+            The time assiociated with the coordinate, will be passed to
+            `~.builtin_frames.ITRS` as the obstime keyword.
+
+        Returns
+        -------
+        `~.builtin_frames.ITRS`
+            An `~.builtin_frames.ITRS` coordinate frame
+            representing the coordinates.
+
+        Notes
+        -----
+
+        The obsgeo array as accessed on a `.WCS` object is a length 6 numpy array
+        where the first three elements are the coordinate in a cartesian
+        representation and the second 3 are the coordinate in a spherical
+        representation.
+
+        This function priorities reading the cartesian coordinates, and will only
+        read the spherical coordinates if the cartesian coordinates are either all
+        zero or any of the cartesian coordinates are non-finite.
+
+        In the case where both the spherical and cartesian coordinates have some
+        non-finite values the spherical coordinates will be returned with the
+        non-finite values included.
+
+        """
+        if (obsgeo is None
+            or len(obsgeo) != 6
+            or np.all(np.array(obsgeo) == 0)
+            or np.all(~np.isfinite(obsgeo))
+        ):  # NOQA
+            raise ValueError(f"Can not parse the 'obsgeo' location ({obsgeo}). "
+                             "obsgeo should be a length 6 non-zero, finite numpy array")
+
+        # If the cartesian coords are zero or have NaNs in them use the spherical ones
+        if np.all(obsgeo[:3] == 0) or np.any(~np.isfinite(obsgeo[:3])):
+            data = SphericalRepresentation(*(obsgeo[3:] * (u.deg, u.deg, u.m)))
+
+        # Otherwise we assume the cartesian ones are valid
+        else:
+            data = CartesianRepresentation(*obsgeo[:3] * u.m)
+
+        return ITRS(data, obstime=obstime)
+
 
 def solar_wcs_frame_mapping(wcs):
     """
@@ -46,18 +111,12 @@ def solar_wcs_frame_mapping(wcs):
     if rsun is not None:
         rsun *= u.m
 
-    # This custom attribute was always used in sunpy < 2.1; these warnings
-    # can be converted into errors in sunpy 3.1
-    if hasattr(wcs, 'rsun'):
-        warnings.warn('Support for the .rsun attribute on a WCS is deprecated. '
-                      'Set observer keywords in the FITS header, or directly set the wcs.wcs.aux '
-                      'values instead.',
-                      SunpyUserWarning)
-        if rsun is None:
-            rsun = wcs.rsun
-        else:
-            warnings.warn('rsun information present in WCS auxillary information, ignoring '
-                          '.rsun', SunpyUserWarning)
+    # TODO: remove these errors in sunpy 4.1
+    bad_attrs = [f'.{attr}' for attr in ['rsun', 'heliographic_observer']
+                 if hasattr(wcs, attr)]
+    if len(bad_attrs):
+        raise ValueError(f"The {' and '.join(bad_attrs)} attribute(s) on a WCS "
+                         "are no longer supported.")
 
     observer = None
     for frame, attr_names in required_attrs.items():
@@ -74,18 +133,18 @@ def solar_wcs_frame_mapping(wcs):
                              attrs[2] * u.m,
                              **kwargs)
 
-    # This custom attribute was always used in sunpy < 2.1; these warnings
-    # can be converted into errors in sunpy 3.1
-    if hasattr(wcs, 'heliographic_observer'):
-        warnings.warn('Support for the .heliographic_observer attribute on a WCS is deprecated. '
-                      'Set observer keywords in the FITS header, or directly set the wcs.wcs.aux '
-                      'values instead.',
-                      SunpyUserWarning)
-        if observer is None:
-            observer = wcs.heliographic_observer
-        else:
-            warnings.warn('Observer information present in WCS auxillary information, ignoring '
-                          '.heliographic_observer', SunpyUserWarning)
+    # Read the observer out of obsgeo for ground based observers
+    if observer is None:
+        try:
+            observer = obsgeo_to_frame(wcs.wcs.obsgeo, dateobs)
+            observer = SkyCoord(observer, rsun=rsun)
+        except ValueError as e:
+            # The helper function assumes you know the obsgeo coords you are
+            # parsing are good, we are not sure, so catch the error.
+
+            # This approach could lead to an invalid observer (i.e. one of the
+            # coords being NaN), but only if the WCS has been constructed like that.
+            log.debug(f"Could not parse obsgeo coordinates from WCS:\n{e}")
 
     # Collect all of the possible frame attributes, although some may be removed later
     frame_args = {'obstime': dateobs}
@@ -94,22 +153,31 @@ def solar_wcs_frame_mapping(wcs):
     if rsun is not None:
         frame_args['rsun'] = rsun
 
+    frame_class = _sunpy_frame_class_from_ctypes(wcs.wcs.ctype)
+
+    if frame_class:
+        if frame_class == HeliographicStonyhurst:
+            frame_args.pop('observer', None)
+        if frame_class == Heliocentric:
+            frame_args.pop('rsun', None)
+
+        return frame_class(**frame_args)
+
+
+def _sunpy_frame_class_from_ctypes(ctypes):
     # Truncate the ctype to the first four letters
-    ctypes = {c[:4] for c in wcs.wcs.ctype}
+    ctypes = {c[:4] for c in ctypes}
 
-    if {'HPLN', 'HPLT'} <= ctypes:
-        return Helioprojective(**frame_args)
+    mapping = {
+        Helioprojective: {'HPLN', 'HPLT'},
+        HeliographicStonyhurst: {'HGLN', 'HGLT'},
+        HeliographicCarrington: {'CRLN', 'CRLT'},
+        Heliocentric: {'SOLX', 'SOLY'},
+    }
 
-    if {'HGLN', 'HGLT'} <= ctypes:
-        frame_args.pop('observer', None)
-        return HeliographicStonyhurst(**frame_args)
-
-    if {'CRLN', 'CRLT'} <= ctypes:
-        return HeliographicCarrington(**frame_args)
-
-    if {'SOLX', 'SOLY'} <= ctypes:
-        frame_args.pop('rsun', None)
-        return Heliocentric(**frame_args)
+    for frame_class, ctype_pair in mapping.items():
+        if ctype_pair <= ctypes:
+            return frame_class
 
 
 def _set_wcs_aux_obs_coord(wcs, obs_frame):
