@@ -2,14 +2,10 @@
 isort:skip_file.
 """
 # flake8: noqa: E402
-import platform
-from distutils.version import LooseVersion
-
 import numpy as np
 import pytest
 
 import astropy.units as u
-asdf = pytest.importorskip('asdf', '2.0')
 from asdf.tests.helpers import assert_roundtrip_tree
 
 import sunpy.map
@@ -24,15 +20,6 @@ def aia171_test_map():
     return sunpy.map.Map(aia_path)
 
 
-# Skip these two tests on windows due to a weird interaction with atomicfile
-# and tmpdir
-skip_windows_asdf = pytest.mark.skipif(
-    (LooseVersion(asdf.__version__) < LooseVersion("2.3.1")
-     and platform.system() == 'Windows'),
-    reason="See https://github.com/spacetelescope/asdf/pull/632")
-
-
-@skip_windows_asdf
 @asdf_entry_points
 def test_genericmap_basic(aia171_test_map, tmpdir):
 
@@ -41,7 +28,6 @@ def test_genericmap_basic(aia171_test_map, tmpdir):
     assert_roundtrip_tree(tree, tmpdir, extensions=SunpyExtension())
 
 
-@skip_windows_asdf
 @asdf_entry_points
 def test_genericmap_mask(aia171_test_map, tmpdir):
 
