@@ -6,28 +6,56 @@ import codecs
 import urllib
 from pathlib import Path
 from collections import OrderedDict
+from urllib.parse import urljoin
+from urllib.request import urlopen
 
 from astropy.utils.decorators import lazyproperty
 
 import sunpy
 import sunpy.util.parfive_helpers as parfive
+from sunpy import log
 from sunpy.time import parse_time
 from sunpy.util.util import partial_key_match
 from sunpy.util.xml import xml_to_dict
 
 __all__ = ['HelioviewerClient']
 
+HELIOVIEWER_API_URLS = [
+    "https://helioviewer-api.ias.u-psud.fr/",
+    "https://api.helioviewer.org/",
+]
+
+
+def check_connection(url):
+    try:
+        resp = urlopen(urljoin(url, "/v2/getDataSources/"))
+        assert resp.getcode() == 200
+        assert isinstance(json.loads(resp.read()), dict)
+        return url
+    except Exception as e:
+        log.debug(f"Unable to connect to {url}:\n {e}")
+        log.info(f"Connection to {url} failed. Retrying with different url.")
+    return None
+
 
 class HelioviewerClient:
     """Helioviewer.org Client"""
 
-    def __init__(self, url="https://api.helioviewer.org/"):
+    def __init__(self, url=None):
         """
         Parameters
         ----------
         url : `str`
             Default URL points to the Helioviewer API.
         """
+        if url is None:
+            for url in HELIOVIEWER_API_URLS:
+                if check_connection(url):
+                    break
+
+        if url is None:
+            raise ValueError("No online helioviewer API can be found.")
+
         self._api = url
 
     @lazyproperty
@@ -110,9 +138,9 @@ class HelioviewerClient:
         Examples
         --------
         >>> from sunpy.net import helioviewer
-        >>> client = helioviewer.HelioviewerClient()  # doctest: +SKIP
-        >>> metadata = client.get_closest_image('2012/01/01', source_id=11)  # doctest: +SKIP
-        >>> print(metadata['date'])  # doctest: +SKIP
+        >>> client = helioviewer.HelioviewerClient()  # doctest: +REMOTE_DATA
+        >>> metadata = client.get_closest_image('2012/01/01', source_id=11)  # doctest: +REMOTE_DATA
+        >>> print(metadata['date'])  # doctest: +REMOTE_DATA
         2012-01-01T00:00:07.000
         """
         if source_id is None:
@@ -177,12 +205,12 @@ class HelioviewerClient:
         --------
         >>> import sunpy.map
         >>> from sunpy.net import helioviewer
-        >>> hv = helioviewer.HelioviewerClient()  # doctest: +SKIP
+        >>> hv = helioviewer.HelioviewerClient()  # doctest: +REMOTE_DATA
         >>> filepath = hv.download_jp2('2012/07/03 14:30:00', observatory='SDO',
-        ...                            instrument='HMI', detector=None, measurement='continuum')  # doctest: +SKIP
-        >>> filepath = hv.download_jp2('2012/07/03 14:30:00', observatory='SDO', measurement='continuum')  # doctest: +SKIP
-        >>> filepath = hv.download_jp2('2012/07/03 14:30:00', instrument='HMI', measurement='continuum')  # doctest: +SKIP
-        >>> aia = sunpy.map.Map(filepath)  # doctest: +SKIP
+        ...                            instrument='HMI', detector=None, measurement='continuum')  # doctest: +REMOTE_DATA
+        >>> filepath = hv.download_jp2('2012/07/03 14:30:00', observatory='SDO', measurement='continuum')  # doctest: +REMOTE_DATA
+        >>> filepath = hv.download_jp2('2012/07/03 14:30:00', instrument='HMI', measurement='continuum')  # doctest: +REMOTE_DATA
+        >>> aia = sunpy.map.Map(filepath)  # doctest: +REMOTE_DATA
         >>> aia.peek()  # doctest: +SKIP
         """
         if source_id is None:
@@ -234,13 +262,13 @@ class HelioviewerClient:
         Examples
         --------
         >>> from sunpy.net import helioviewer
-        >>> hv = helioviewer.HelioviewerClient()  # doctest: +SKIP
+        >>> hv = helioviewer.HelioviewerClient()  # doctest: +REMOTE_DATA
         >>> header = hv.get_jp2_header('2012/07/03', observatory='SDO',
-        ...                            instrument='HMI', detector=None, measurement='continuum')  # doctest: +SKIP
+        ...                            instrument='HMI', detector=None, measurement='continuum')  # doctest: +REMOTE_DATA
         >>> # The key 'fits' can be used to get the fits header information
-        >>> fits_header = header['fits']  # doctest: +SKIP
+        >>> fits_header = header['fits']  # doctest: +REMOTE_DATA
         >>> # The keys 'helioviewer' can be used to extract the helioviewer specific metadata.
-        >>> helioviewer_meta_data = header['helioviewer']  # doctest: +SKIP
+        >>> helioviewer_meta_data = header['helioviewer']  # doctest: +REMOTE_DATA
         """
         if jp2_id is None:
             jp2_id = self.get_closest_image(
@@ -367,13 +395,13 @@ class HelioviewerClient:
         Examples
         --------
         >>> from sunpy.net.helioviewer import HelioviewerClient
-        >>> hv = HelioviewerClient()  # doctest: +SKIP
+        >>> hv = HelioviewerClient()  # doctest: +REMOTE_DATA
         >>> file = hv.download_png('2012/07/16 10:08:00', 2.4,
         ...                        "[SDO,AIA,AIA,171,1,100]",
-        ...                        x0=0, y0=0, width=1024, height=1024)   # doctest: +SKIP
+        ...                        x0=0, y0=0, width=1024, height=1024)   # doctest: +REMOTE_DATA
         >>> file = hv.download_png('2012/07/16 10:08:00', 4.8,
         ...                        "[SDO,AIA,AIA,171,1,100],[SOHO,LASCO,C2,white-light,1,100]",
-        ...                        x1=-2800, x2=2800, y1=-2800, y2=2800)   # doctest: +SKIP
+        ...                        x1=-2800, x2=2800, y1=-2800, y2=2800)   # doctest: +REMOTE_DATA
         """
         params = {
             "action": "takeScreenshot",
