@@ -67,10 +67,12 @@ def get_hash_library_name():
     """
     Generate the hash library name for this env.
     """
+    import mpl_animators
+    animators_version = "dev" if "+" in mpl_animators.__version__ else mpl_animators.__version__.replace('.', '')
     ft2_version = f"{mpl.ft2font.__freetype_version__.replace('.', '')}"
     mpl_version = "dev" if "+" in mpl.__version__ else mpl.__version__.replace('.', '')
     astropy_version = "dev" if "dev" in astropy.__version__ else astropy.__version__.replace('.', '')
-    return f"figure_hashes_mpl_{mpl_version}_ft_{ft2_version}_astropy_{astropy_version}.json"
+    return f"figure_hashes_mpl_{mpl_version}_ft_{ft2_version}_astropy_{astropy_version}_animators_{animators_version}.json"
 
 
 def figure_test(test_function):
